#ifndef RENDERER_H
#define RENDERER_H

#include <SDL2/SDL.h>
#include <SDL2/SDL_ttf.h>
#include <string>
#include "AssetManager.h"

class Renderer {
public:
    Renderer(SDL_Renderer* r, AssetManager* a);

    void clear();
    void present();
    void drawTexture(SDL_Texture* tex, int x, int y, int w, int h);
    void drawImage(const std::string& path, int x, int y, int w, int h);
    void drawText(const std::string& text, int x, int y, SDL_Color color);
    void drawInt(int value, int x, int y, SDL_Color color);

private:
    SDL_Renderer* renderer;
    AssetManager* assets;
};

#endif
